@@ -16,8 +16,10 @@ from .slim_metadata import _decode_mutation_pre_nucleotides, _set_metadata_schem
 
 INDIVIDUAL_ALIVE = 2**16
 INDIVIDUAL_REMEMBERED = 2**17
-# no longer used but keep for a while
-INDIVIDUAL_FIRST_GEN = 2**18
+INDIVIDUAL_RETAINED = 2**18
+# deprecated but keep it around for backwards compatibility
+# (also, it means effectively the same thing as RETAINED)
+INDIVIDUAL_FIRST_GEN = INDIVIDUAL_RETAINED
 
 # A nucleotide k in mutation metadata actually means
 # something that in reference_sequence is NUCLEOTIDES[k]
@@ -153,7 +155,7 @@ class SlimTreeSequence(tskit.TreeSequence):
     def __init__(self, ts, reference_sequence=None, legacy_metadata=False):
         self.legacy_metadata = legacy_metadata
         if not (isinstance(ts.metadata, dict) and 'SLiM' in ts.metadata
-                and ts.metadata['SLiM']['file_version'] == slim_file_version):
+                and ts.metadata['SLiM']['file_version'] in compatible_slim_file_versions):
             tables = ts.dump_tables()
             if not (isinstance(tables.metadata, dict) and 'SLiM' in tables.metadata):
                 _set_metadata_from_provenance(tables)
@@ -441,21 +443,11 @@ class SlimTreeSequence(tskit.TreeSequence):
             raise ValueError("The keep_first_generation argument is deprecated:"
                              "the FIRST_GEN flag is no longer used.")
 
-        # toggle for hacks below to deal with old msprime
-        discrete_msprime = hasattr(msprime, "RateMap")
-
-        if recombination_rate is not None:
-            if recombination_map is not None:
-                raise ValueError("Cannot specify length/recombination_rate along with a recombination map")
-            if discrete_msprime:
-                recombination_map = msprime.RecombinationMap(positions = [0.0, self.sequence_length],
-                                                             rates = [recombination_rate, 0.0])
-            else:
-                recombination_map = msprime.RecombinationMap(positions = [0.0, self.sequence_length],
-                                                             rates = [recombination_rate, 0.0],
-                                                             num_loci = int(self.sequence_length))
-        if discrete_msprime and ('discrete_genome' not in kwargs):
-            kwargs['discrete_genome'] = True
+        if recombination_map is None:
+            recombination_map = msprime.RecombinationMap(
+                       positions = [0.0, self.sequence_length],
+                       rates = [recombination_rate, 0.0],
+                       num_loci = int(self.sequence_length))
 
         if population_configurations is None:
             population_configurations = [msprime.PopulationConfiguration()
@@ -612,8 +604,9 @@ class SlimTreeSequence(tskit.TreeSequence):
         then those individuals might not have survived until "late()" of that
         time step. Since SLiM does not record the stage at which individuals
         were Remembered, you can specify this by setting ``remembered_stages``:
-        it should be the stage during which *all* calls to sim.treeSeqRememberIndividuals,
-        as well as to sim.treeSeqOutput(), were made.
+        it should be the stage during which *all* calls to
+        ``sim.treeSeqRememberIndividuals()``,  as well as to ``sim.treeSeqOutput()``,
+        were made.
 
         Note also that in nonWF models, birth occurs before "early()", so the
         possible parents in a given time step are those that are alive in
@@ -627,7 +620,7 @@ class SlimTreeSequence(tskit.TreeSequence):
         :param str stage: The stage in the SLiM life cycle that we are inquiring
             about (either "early" or "late"; defaults to "late").
         :param str remembered_stage: The stage in the SLiM life cycle
-            that individuals were Remembered during (defaults to the stage the
+            during which individuals were Remembered (defaults to the stage the
             tree sequence was recorded at, stored in metadata).
         :param int population: If given, return only individuals in the
             population(s) with these population ID(s).
@@ -714,8 +707,8 @@ class SlimTreeSequence(tskit.TreeSequence):
         :param float time: The reference time ago.
         :param str stage: The stage in the SLiM life cycle used to determine who
             is alive (either "early" or "late"; defaults to "late").
-        :param str remembered_stage: The stage in the SLiM life cycle that
-            individuals were Remembered during.
+        :param str remembered_stage: The stage in the SLiM life cycle during which
+            individuals were Remembered.
         """
         ages = np.repeat(np.nan, self.num_individuals)
         alive = self.individuals_alive_at(time, stage=stage,
@@ -768,33 +761,20 @@ class SlimTreeSequence(tskit.TreeSequence):
             This method is deprecated, because from SLiM version 3.5
             the first generation individuals are no longer marked as such:
             only tree sequences from older versions of SLiM will have
-            these individuals.
+            these individuals. As part of this, the INDIVIDUAL_FIRST_GEN
+            flag does not exist, so this function returns individuals with
+            the INDIVIDUAL_RETAINED flag instead.
         """
         warnings.warn(
                 "This method is deprecated: SLiM no longer marks individuals as "
                 "'first generation' any longer - you must explicitly Remember them "
-                "to retain them in the tree sequence.", FutureWarning)
-        return np.where(self.tables.individuals.flags & INDIVIDUAL_FIRST_GEN > 0)[0]
+                "to keep them in the tree sequence. Returning *retained* individuals "
+                "instead.", FutureWarning)
+        return np.where(self.tables.individuals.flags & INDIVIDUAL_RETAINED > 0)[0]
 
-    def has_individual_parents(self):
-        '''
-        Finds which individuals have both their parent individuals also present
-        in the tree sequence, as far as we can tell. To do this, we return the
-        IDs of individuals for which:
-
-        - all edges terminating in that individual's nodes are in individuals,
-        - each of the individual's nodes inherit from a single individual only,
-        - those parental individuals were alive when the individual was born,
-        - the parental individuals account for two whole genomes.
-
-        This returns a boolean array indicating for each individual whether all
-        these are true.
-
-        See :meth:`.individuals_alive_at` for further discussion about how
-        this is determined based on when the individuals were Remembered.
-
-        :return: A boolean array of length equal to ``targets``.
-        '''
+    def _do_individual_parents_stuff(self, return_parents=False):
+        # Helper for has_individual_parents and individual_parents,
+        # which share a lot of machinery.
         edges = self.tables.edges
         nodes = self.tables.nodes
         edge_parent_indiv = nodes.individual[edges.parent]
@@ -820,7 +800,6 @@ class SlimTreeSequence(tskit.TreeSequence):
         else:
             parent_deaths = parent_births - self.individual_ages[edge_parent_indiv[indiv_edges]]
             alive_edges[indiv_edges] = (child_births + 1 >= parent_deaths)
-        # total genome inherited from parents
         edge_spans = edges.right - edges.left
         parental_span = np.bincount(edge_child_indiv[alive_edges],
                 weights=edge_spans[alive_edges], minlength=self.num_individuals)
@@ -828,8 +807,56 @@ class SlimTreeSequence(tskit.TreeSequence):
         # in this individual, but this is unnecessary as the entire genome is
         # accounted for
         has_all_parents = (parental_span == 2 * self.sequence_length)
-        return has_all_parents
+        if return_parents:
+            full_parent_edges = np.logical_and(
+                    alive_edges,
+                    has_all_parents[edge_child_indiv])
+            parents = np.unique(np.column_stack(
+                            [edge_parent_indiv[full_parent_edges],
+                             edge_child_indiv[full_parent_edges]]
+                            ), axis=0)
+            return parents
+        else:
+            return has_all_parents
 
+    def individual_parents(self):
+        '''
+        Finds all parent-child relationships in the tree sequence (as far as we
+        can tell). The output will be a two-column array with row [i,j]
+        indicating that individual i is a parent of individual j.  See
+        :meth:`.has_individual_parents` for exactly which parents are returned.
+
+        See :meth:`.individuals_alive_at` for further discussion about how
+        this is determined based on when the individuals were Remembered.
+
+        :param array individuals: The IDs of individuals that parents should be found
+            for (defaults to all individuals).
+        :return: An array of individual IDs, with row [i, j] if individual i is
+            a parent of individual j.
+        '''
+        return self._do_individual_parents_stuff(return_parents=True)
+
+    def has_individual_parents(self):
+        '''
+        Finds which individuals have both their parent individuals also present
+        in the tree sequence, as far as we can tell. To do this, we return a
+        boolean array with True for those individuals for which:
+
+        - all edges terminating in that individual's nodes are in individuals,
+        - each of the individual's nodes inherit from a single individual only,
+        - those parental individuals were alive when the individual was born,
+        - the parental individuals account for two whole genomes.
+
+        This returns a boolean array indicating for each individual whether all
+        these are true. Note in particular that individuals with only *one*
+        recorded parent are *not* counted as "having parents".
+
+        See :meth:`.individuals_alive_at` for further discussion about how
+        this is determined based on when the individuals were Remembered.
+
+        :return: A boolean array of length equal to ``targets``.
+        '''
+        return self._do_individual_parents_stuff(return_parents=False)
 
 def _set_metadata_from_provenance(tables):
     # note this uses defaults on keys not present in provenance,
