@@ -1,19 +1,19 @@
 """
 Test cases for provenance handling.
 """
-from __future__ import print_function
-from __future__ import division
-
-import tests
-import unittest
-import random
 import json
+import os
+import random
+
 import tskit
 import numpy as np
 import pytest
 import msprime
 import pyslim
 
+import tests
+from .recipe_specs import recipe_specs, recipe_eq
+
 # *Note:* it is now deprecated to extract information from provenance,
 # but we still need to do it, to be able to load old file versions.
 
@@ -122,64 +122,86 @@ old_provenance_examples = [_slim_v3_0_example, _slim_v3_1_example, _slim_v3_3_1_
 
 
 class TestProvenance(tests.PyslimTestCase):
-
+    script_dir = os.path.dirname(os.path.realpath(__file__))
+    
     def get_0_1_slim_examples(self):
-        for filename in ['tests/examples/recipe_WF.v3.0.trees',
-                         'tests/examples/recipe_nonWF.v3.0.trees']:
+        for filename in [
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_WF.v3.0.trees'),
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_nonWF.v3.0.trees'),
+        ]:
             with pytest.warns(Warning):
                 yield tskit.load(filename)
 
     def get_0_2_slim_examples(self):
-        for filename in ['tests/examples/recipe_WF.v3.2.trees',
-                         'tests/examples/recipe_nonWF.v3.2.trees']:
+        for filename in [
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_WF.v3.2.trees'),
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_nonWF.v3.2.trees'),
+        ]:
             with pytest.warns(Warning):
                 yield tskit.load(filename)
 
     def get_0_3_slim_examples(self):
-        for filename in ['tests/examples/recipe_WF.v3.3.1.trees',
-                         'tests/examples/recipe_nonWF.v3.3.1.trees']:
+        for filename in [
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_WF.v3.3.1.trees'),
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_nonWF.v3.3.1.trees'),
+        ]:
             with pytest.warns(Warning):
                 yield tskit.load(filename)
 
     def get_0_4_slim_examples(self):
-        for filename in ['tests/examples/recipe_WF.v3.4.trees',
-                         'tests/examples/recipe_nonWF.v3.4.trees']:
+        for filename in [
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_WF.v3.4.trees'),
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_nonWF.v3.4.trees'),
+        ]:
             with pytest.warns(Warning):
                 yield tskit.load(filename)
 
-    def test_get_provenance(self):
-        for ts in self.get_slim_examples(WF=True):
-            with pytest.warns(Warning):
-                prov = ts.slim_provenance
-            assert prov.model_type == "WF"
-            assert prov == pyslim.get_provenance(ts)
-            assert prov == pyslim.get_provenance(ts.tables)
-        for ts in self.get_slim_examples(nonWF=True):
-            with pytest.warns(Warning):
-                prov = ts.slim_provenance
-            assert prov.model_type == "nonWF"
-            assert prov == pyslim.get_provenance(ts)
-            assert prov == pyslim.get_provenance(ts.tables)
+    def get_0_5_slim_examples(self):
+        for filename in [
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_WF.v3.5.trees'),
+            os.path.join(self.script_dir, 'test_recipes', 'recipe_nonWF.v3.5.trees'),
+        ]:
+            # no warning: current file version!
+            yield tskit.load(filename)
 
-    def test_get_all_provenances(self):
-        for ts in self.get_slim_examples(WF=True):
-            rts = self.run_msprime_restart(ts, WF=True)
-            provenances = rts.slim_provenances
-            assert len(provenances) == 2
-            with pytest.warns(Warning):
-                last_prov = ts.slim_provenance
-            assert last_prov == provenances[0]
-            # mrts = pyslim.SlimTreeSequence(msprime.mutate(rts, rate=0.001))
-            j = 0
-            for p in rts.provenances():
-                is_slim, _ = pyslim.slim_provenance_version(p)
-                if is_slim:
-                    sp = pyslim.parse_provenance(p)
-                    assert provenances[j] == sp
-                    j += 1
-                else:
-                    with pytest.raises(ValueError):
-                        pyslim.parse_provenance(p)
+    @pytest.mark.parametrize("recipe", recipe_eq("WF"), indirect=True)    
+    def test_get_WF_provenance(self, recipe):
+        ts = recipe["ts"]
+        with pytest.warns(Warning):
+            prov = ts.slim_provenance
+        assert prov.model_type == "WF"
+        assert prov == pyslim.get_provenance(ts)
+        assert prov == pyslim.get_provenance(ts.tables)
+
+    @pytest.mark.parametrize("recipe", recipe_eq("nonWF"), indirect=True)    
+    def test_get_nonWF_provenance(self, recipe):
+        ts = recipe["ts"]
+        with pytest.warns(Warning):
+            prov = ts.slim_provenance
+        assert prov.model_type == "nonWF"
+        assert prov == pyslim.get_provenance(ts)
+        assert prov == pyslim.get_provenance(ts.tables)
+
+    @pytest.mark.parametrize("recipe", recipe_eq("WF"), indirect=True)    
+    def test_get_all_provenances(self, recipe, helper_functions, tmp_path):
+        ts = recipe["ts"]
+        rts = helper_functions.run_msprime_restart(ts, tmp_path, WF=True)
+        provenances = rts.slim_provenances
+        assert len(provenances) == 2
+        with pytest.warns(Warning):
+            last_prov = ts.slim_provenance
+        assert last_prov == provenances[0]
+        # mrts = pyslim.SlimTreeSequence(msprime.mutate(rts, rate=0.001))
+        j = 0
+        for p in rts.provenances():
+            is_slim, _ = pyslim.slim_provenance_version(p)
+            if is_slim:
+                sp = pyslim.parse_provenance(p)
+                assert provenances[j] == sp
+                j += 1
+            else:
+                with pytest.raises(ValueError):
+                    pyslim.parse_provenance(p)
 
     def test_provenance_creation(self):
         record = pyslim.make_pyslim_provenance_dict()
@@ -311,5 +333,30 @@ class TestProvenance(tests.PyslimTestCase):
                 if t.parent(u) != tskit.NULL:
                     assert t.branch_length(u) == pt.branch_length(u)
 
+    def test_convert_0_5_files(self):
+        # current file version!
+        for ts in self.get_0_5_slim_examples():
+            pts = pyslim.SlimTreeSequence(ts)
+            assert ts.num_provenances == 1
+            assert pts.num_provenances == 1
+            assert ts.provenance(0).record == pts.provenance(0).record
+            record = json.loads(ts.provenance(0).record)
+            assert isinstance(pts.metadata, dict)
+            assert 'SLiM' in pts.metadata
+            assert record['parameters']['model_type'] == pts.metadata['SLiM']['model_type']
+            assert record['slim']['generation'] == pts.metadata['SLiM']['generation']
+            assert list(ts.samples()) == list(pts.samples())
+            assert np.array_equal(ts.tables.nodes.flags, pts.tables.nodes.flags)
+            samples = list(ts.samples())
+            t = ts.first()
+            pt = pts.first()
+            for _ in range(20):
+                u = random.sample(samples, 1)[0]
+                assert t.parent(u) == pt.parent(u)
+                if t.parent(u) != tskit.NULL:
+                    assert t.branch_length(u) == pt.branch_length(u)
+
+
+
 
 
